# lhub
Python package for interacting with LogicHub APIs

# Version History
### 0.1.x
* Various pre-beta changes prior to widespread use

### 0.1.7.0, 2022-04-26
* Stripped out the Logging class and moved to lhub_cli. Default logger is now the builtin logging module with logging disabled.
* Minor backend and output improvements

### 0.2.0, YYYY-MM-DD
* Major overhaul

### 0.2.2, YYYY-MM-DD
* Numerous new actions and updates
* Various improvements to custom exceptions
